@@ -8,10 +8,10 @@ Components.utils.import("resource://gre/modules/Preferences.jsm");
 Components.utils.import("resource://calendar/modules/calUtils.jsm");
 Components.utils.import("resource://calendar/modules/calProviderUtils.jsm");
 
-const REGISTRY_BRANCH = "calendar.registry.";
-const DB_SCHEMA_VERSION = 10;
-const MAX_INT = Math.pow(2, 31) - 1;
-const MIN_INT = -MAX_INT;
+var REGISTRY_BRANCH = "calendar.registry.";
+var DB_SCHEMA_VERSION = 10;
+var MAX_INT = Math.pow(2, 31) - 1;
+var MIN_INT = -MAX_INT;
 
 function calCalendarManager() {
     this.wrappedJSObject = this;
@@ -19,8 +19,8 @@ function calCalendarManager() {
     this.mCalendarObservers = new calListenerBag(Components.interfaces.calIObserver);
 }
 
-const calCalendarManagerClassID = Components.ID("{f42585e7-e736-4600-985d-9624c1c51992}");
-const calCalendarManagerInterfaces = [
+var calCalendarManagerClassID = Components.ID("{f42585e7-e736-4600-985d-9624c1c51992}");
+var calCalendarManagerInterfaces = [
     Components.interfaces.calICalendarManager,
     Components.interfaces.calIStartupService,
     Components.interfaces.nsIObserver,
@@ -36,9 +36,9 @@ calCalendarManager.prototype = {
         flags: Components.interfaces.nsIClassInfo.SINGLETON
     }),
 
-    get networkCalendarCount() this.mNetworkCalendarCount,
-    get readOnlyCalendarCount() this.mReadonlyCalendarCount,
-    get calendarCount() this.mCalendarCount,
+    get networkCalendarCount() { return this.mNetworkCalendarCount; },
+    get readOnlyCalendarCount() { return this.mReadonlyCalendarCount; },
+    get calendarCount() { return this.mCalendarCount; },
 
     // calIStartupService:
     startup: function ccm_startup(aCompleteListener) {
@@ -64,7 +64,8 @@ calCalendarManager.prototype = {
     },
 
     shutdown: function ccm_shutdown(aCompleteListener) {
-        for each (var calendar in this.mCache) {
+        for (let id in this.mCache) {
+            let calendar = this.mCache[id];
             calendar.removeObserver(this.mCalObservers[calendar.id]);
         }
 
@@ -98,14 +99,15 @@ calCalendarManager.prototype = {
             case "timer-callback":
                 // Refresh all the calendars that can be refreshed.
                 var cals = this.getCalendars({});
-                for each (var calendar in cals) {
+                for (var calendar of cals) {
                     if (!calendar.getProperty("disabled") && calendar.canRefresh) {
                         calendar.refresh();
                     }
                 }
                 break;
             case "network:offline-status-changed":
-                for each (var calendar in this.mCache) {
+                for (var id in this.mCache) {
+                    let calendar = this.mCache[id];
                     if (calendar instanceof calCachedCalendar) {
                         calendar.onOfflineStatusChanged(aData == "offline");
                     }
@@ -150,7 +152,7 @@ calCalendarManager.prototype = {
                     // the "cal" namespace defined
                     let ua = httpChannel.getRequestHeader("User-Agent");
                     let calUAString = Preferences.get("calendar.useragent.extra");
-                    if (calUAString && ua.indexOf(calUAString) < 0) {
+                    if (calUAString && !ua.includes(calUAString)) {
                         // User-Agent is not a mergeable header. We need to
                         // merge the user agent ourselves.
                         httpChannel.setRequestHeader("User-Agent",
@@ -299,7 +301,8 @@ calCalendarManager.prototype = {
             }
 
             let sortOrderAr = [];
-            for each (let s in sortOrder) {
+            for (let id in sortOrder) {
+                let s = sortOrder[id];
                 sortOrderAr.push(s);
             }
             Preferences.set("calendar.list.sortOrder", sortOrderAr.join(" "));
@@ -644,7 +647,8 @@ calCalendarManager.prototype = {
     getCalendars: function cmgr_getCalendars(count) {
         this.assureCache();
         var calendars = [];
-        for each (var calendar in this.mCache) {
+        for (var id in this.mCache) {
+            let calendar = this.mCache[id];
             calendars.push(calendar);
         }
         count.value = calendars.length;
@@ -657,7 +661,7 @@ calCalendarManager.prototype = {
             this.mCalObservers = {};
 
             let allCals = {};
-            for each (let key in Services.prefs.getChildList(REGISTRY_BRANCH)) { // merge down all keys
+            for (let key of Services.prefs.getChildList(REGISTRY_BRANCH)) { // merge down all keys
                 allCals[key.substring(0, key.indexOf(".", REGISTRY_BRANCH.length))] = true;
             }
 
@@ -705,7 +709,8 @@ calCalendarManager.prototype = {
 
             // do refreshing in a second step, when *all* calendars are already available
             // via getCalendars():
-            for each (let calendar in this.mCache) {
+            for (let id in this.mCache) {
+                let calendar = this.mCache[id];
                 if (!calendar.getProperty("disabled") && calendar.canRefresh) {
                     calendar.refresh();
                 }
@@ -758,14 +763,14 @@ calCalendarManager.prototype = {
     },
 
     mObservers: null,
-    addObserver: function(aObserver) this.mObservers.add(aObserver),
-    removeObserver: function(aObserver) this.mObservers.remove(aObserver),
-    notifyObservers: function(functionName, args) this.mObservers.notify(functionName, args),
+    addObserver: function(aObserver) { return this.mObservers.add(aObserver); },
+    removeObserver: function(aObserver) { return this.mObservers.remove(aObserver); },
+    notifyObservers: function(functionName, args) { return this.mObservers.notify(functionName, args); },
 
     mCalendarObservers: null,
-    addCalendarObserver: function(aObserver) this.mCalendarObservers.add(aObserver),
-    removeCalendarObserver: function(aObserver) this.mCalendarObservers.remove(aObserver),
-    notifyCalendarObservers: function(functionName, args) this.mCalendarObservers.notify(functionName, args)
+    addCalendarObserver: function(aObserver) { return this.mCalendarObservers.add(aObserver); },
+    removeCalendarObserver: function(aObserver) { return this.mCalendarObservers.remove(aObserver); },
+    notifyCalendarObservers: function(functionName, args) { return this.mCalendarObservers.notify(functionName, args); }
 };
 
 function equalMessage(msg1, msg2) {
@@ -796,12 +801,12 @@ calMgrCalendarObserver.prototype = {
     ]),
 
     // calIObserver:
-    onStartBatch: function() this.calMgr.notifyCalendarObservers("onStartBatch", arguments),
-    onEndBatch: function() this.calMgr.notifyCalendarObservers("onEndBatch", arguments),
-    onLoad: function(calendar) this.calMgr.notifyCalendarObservers("onLoad", arguments),
-    onAddItem: function(aItem) this.calMgr.notifyCalendarObservers("onAddItem", arguments),
-    onModifyItem: function(aNewItem, aOldItem) this.calMgr.notifyCalendarObservers("onModifyItem", arguments),
-    onDeleteItem: function(aDeletedItem) this.calMgr.notifyCalendarObservers("onDeleteItem", arguments),
+    onStartBatch: function() { return this.calMgr.notifyCalendarObservers("onStartBatch", arguments); },
+    onEndBatch: function() { return this.calMgr.notifyCalendarObservers("onEndBatch", arguments); },
+    onLoad: function(calendar) { return this.calMgr.notifyCalendarObservers("onLoad", arguments); },
+    onAddItem: function(aItem) { return this.calMgr.notifyCalendarObservers("onAddItem", arguments); },
+    onModifyItem: function(aNewItem, aOldItem) { return this.calMgr.notifyCalendarObservers("onModifyItem", arguments); },
+    onDeleteItem: function(aDeletedItem) { return this.calMgr.notifyCalendarObservers("onDeleteItem", arguments); },
     onError: function(aCalendar, aErrNo, aMessage) {
         this.calMgr.notifyCalendarObservers("onError", arguments);
         this.announceError(aCalendar, aErrNo, aMessage);
@@ -874,7 +879,7 @@ calMgrCalendarObserver.prototype = {
                                 "calendar-main-default",
                                 "readOnly",
                                 "imip.identity.key"];
-            for each (let prop in propsToCopy ) {
+            for (let prop of propsToCopy) {
               newCal.setProperty(prop,
                                  aCalendar.getProperty(prop));
             }
@@ -1069,8 +1074,7 @@ var gCalendarManagerAddonListener = {
         const features = "chrome,titlebar,resizable,modal";
         let calMgr = cal.getCalendarManager();
         let affectedCalendars =
-            [ calendar for each (calendar in calMgr.getCalendars({}))
-              if (calendar.providerID == aAddon.id) ];
+            calMgr.getCalendars({}).filter(calendar => calendar.providerID == aAddon.id);
         if (!affectedCalendars.length) {
             // If no calendars are affected, then everything is fine.
             return true;
