@@ -4,17 +4,20 @@
 
 Components.utils.import("resource://gre/modules/Services.jsm");
 Components.utils.import("resource://gre/modules/Preferences.jsm");
+Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
-function Synthetic(aOpen, aDuration) {
+function Synthetic(aOpen, aDuration, aMultiday) {
     this.open = aOpen;
     this.duration = aDuration;
+    this.multiday = aMultiday;
 }
 
 var agendaListbox = {
     agendaListboxControl: null,
-    pendingRefresh: null,
+    mPendingRefreshJobs: null,
     kDefaultTimezone: null,
-    showsToday: false
+    showsToday: false,
+    soonDays: 5
 };
 
 /**
@@ -27,17 +30,31 @@ function initAgendaListbox() {
     var showTodayHeader = (document.getElementById("today-header-hidden").getAttribute("checked") == "true");
     var showTomorrowHeader = (document.getElementById("tomorrow-header-hidden").getAttribute("checked") == "true");
     var showSoonHeader = (document.getElementById("nextweek-header-hidden").getAttribute("checked") == "true");
-    this.today = new Synthetic(showTodayHeader, 1);
+    this.today = new Synthetic(showTodayHeader, 1, false);
     this.addPeriodListItem(this.today, "today-header");
-    this.tomorrow = new Synthetic(showTomorrowHeader, 1);
-    var soondays = Preferences.get("calendar.agendaListbox.soondays", 5);
-    this.soon = new Synthetic(showSoonHeader, soondays);
+    this.tomorrow = new Synthetic(showTomorrowHeader, 1, false);
+    this.soonDays = getSoondaysPreference();
+    this.soon = new Synthetic(showSoonHeader, this.soonDays, true);
     this.periods = [this.today, this.tomorrow, this.soon];
+    this.mPendingRefreshJobs = new Map();
+
+    var prefObserver = {
+        observe: function aL_observe(aSubject, aTopic, aPrefName) {
+            switch (aPrefName) {
+                case "calendar.agendaListbox.soondays":
+                    agendaListbox.soonDays = getSoondaysPreference();
+                    agendaListbox.updateSoonSection();
+                    break;
+            }
+        }
+    }
+    Services.prefs.addObserver("calendar.agendaListbox", prefObserver, false);
 
     // Make sure the agenda listbox is unloaded
     var self = this;
     window.addEventListener("unload",
                             function unload_agendaListbox() {
+                                Services.prefs.removeObserver("calendar.agendaListbox", prefObserver);
                                 self.uninit();
                             },
                             false);
@@ -52,7 +69,7 @@ function uninit() {
         this.calendar.removeObserver(this.calendarObserver);
     }
 
-    for each (var period in this.periods) {
+    for (var period of this.periods) {
         if (period.listItem) {
             period.listItem.getCheckbox()
                   .removeEventListener("CheckboxStateChange",
@@ -392,7 +409,7 @@ function isBefore(aItem, aCompItem, aPeriod) {
 }
 
 /**
- * Returns the a start or end date of an item according to which of them
+ * Returns the start or end date of an item according to which of them
  * must be displayed in a given period of the agenda
  *
  * @param aItem         The item to compare.
@@ -499,8 +516,8 @@ function deleteItem(aItem, aMoveSelection) {
  */
 agendaListbox.deleteItemsFromCalendar =
 function deleteItemsFromCalendar(aCalendar) {
-    let childNodes = Array.slice(this.agendaListboxControl.childNodes);
-    for each (let childNode in childNodes) {
+    let childNodes = Array.from(this.agendaListboxControl.childNodes);
+    for (let childNode of childNodes) {
         if (childNode && childNode.occurrence
             && childNode.occurrence.calendar.id == aCalendar.id) {
             childNode.remove();
@@ -603,35 +620,89 @@ function setupContextMenu(popup) {
  */
 agendaListbox.refreshCalendarQuery =
 function refreshCalendarQuery(aStart, aEnd, aCalendar) {
-    let pendingRefresh = cal.wrapInstance(this.pendingRefresh, Components.interfaces.calIOperation);
-    if (this.pendingRefresh) {
-        if (pendingRefresh) {
-            this.pendingRefresh = null;
-            pendingRefresh.cancel(null);
-        } else {
-            return;
+    let refreshJob = {
+        QueryInterface: XPCOMUtils.generateQI([Components.interfaces.calIOperationListener]),
+        agendaListbox: this,
+        calendar: null,
+        calId: null,
+        operation: null,
+        cancelled: false,
+
+        onOperationComplete: function(aCalendar, aStatus, aOperationType, aId, aDateTime) {
+            if (this.agendaListbox.mPendingRefreshJobs.has(this.calId)) {
+                this.agendaListbox.mPendingRefreshJobs.delete(this.calId);
+            }
+
+            if (!this.cancelled) {
+                setCurrentEvent();
+            }
+        },
+
+        onGetResult: function(aCalendar, aStatus, aItemType, aDetail, aCount, aItems) {
+            if (this.cancelled || !Components.isSuccessCode(aStatus)) {
+                return;
+            }
+            for (let item of aItems) {
+                this.agendaListbox.addItem(item);
+            }
+        },
+
+        cancel: function() {
+            this.cancelled = true;
+            let op = cal.wrapInstance(this.operation, Components.interfaces.calIOperation);
+            if (op && op.isPending) {
+                op.cancel();
+                this.operation = null;
+            }
+        },
+
+        execute: function(aStart, aEnd, aCalendar) {
+            if (!(aStart || aEnd || aCalendar)) {
+                this.agendaListbox.removeListItems();
+            }
+
+            if (!aCalendar) {
+                aCalendar = this.agendaListbox.calendar;
+            }
+            if (!aStart) {
+                aStart = this.agendaListbox.getStart();
+            }
+            if (!aEnd) {
+                aEnd = this.agendaListbox.getEnd();
+            }
+            if (!(aStart || aEnd || aCalendar)) {
+                return;
+            }
+
+            if (aCalendar.type == "composite") {
+                // we're refreshing from the composite calendar, so we can cancel
+                // all other pending refresh jobs.
+                this.calId = "composite";
+                for (let job of this.agendaListbox.mPendingRefreshJobs.values()) {
+                    job.cancel();
+                }
+                this.agendaListbox.mPendingRefreshJobs.clear();
+            } else {
+                this.calId = aCalendar.id;
+                if (this.agendaListbox.mPendingRefreshJobs.has(this.calId)) {
+                    this.agendaListbox.mPendingRefreshJobs.get(this.calId).cancel();
+                    this.agendaListbox.mPendingRefreshJobs.delete(this.calId);
+                }
+            }
+            this.calendar = aCalendar;
+
+            let filter = this.calendar.ITEM_FILTER_CLASS_OCCURRENCES |
+                         this.calendar.ITEM_FILTER_TYPE_EVENT;
+            let op = this.calendar.getItems(filter, 0, aStart, aEnd, this);
+            op = cal.wrapInstance(op, Components.interfaces.calIOperation);
+            if (op && op.isPending) {
+                this.operation = op;
+                this.agendaListbox.mPendingRefreshJobs.set(this.calId, this);
+            }
         }
-    }
-    if (!(aStart || aEnd || aCalendar)) {
-        this.removeListItems();
-    }
-    if (!aStart) {
-        aStart = this.getStart();
-    }
-    if (!aEnd) {
-        aEnd = this.getEnd();
-    }
-    if (aStart && aEnd) {
-        var filter = this.calendar.ITEM_FILTER_CLASS_OCCURRENCES |
-                     this.calendar.ITEM_FILTER_TYPE_EVENT;
-        this.pendingRefresh = true;
-        let refreshCalendar = aCalendar || this.calendar;
-        pendingRefresh = refreshCalendar.getItems(filter, 0, aStart, aEnd,
-                                                  this.calendarOpListener);
-        if (pendingRefresh && pendingRefresh.isPending) { // support for calIOperation
-            this.pendingRefresh = pendingRefresh;
-        }
-    }
+    };
+
+    refreshJob.execute(aStart, aEnd, aCalendar);
 };
 
 /**
@@ -829,29 +900,6 @@ agendaListbox.calendarOpListener = {
     agendaListbox : agendaListbox
 };
 
-/**
- * Called when all items have been retrieved from the calendar.
- * @see calIOperationListener
- */
-agendaListbox.calendarOpListener.onOperationComplete =
-function listener_onOperationComplete(calendar, status, optype, id,
-                                      detail) {
-    // signal that the current operation finished.
-    this.agendaListbox.pendingRefresh = null;
-    setCurrentEvent();
-};
-
-/**
- * Called when an item has been retrieved, adds all items to the agenda listbox.
- * @see calIOperationListener
- */
-agendaListbox.calendarOpListener.onGetResult =
-function listener_onGetResult(calendar, status, itemtype, detail, count, items) {
-    if (!Components.isSuccessCode(status))
-        return;
-    items.forEach(this.agendaListbox.addItem, this.agendaListbox);
-};
-
 /**
  * Calendar and composite observer, used to keep agenda listbox up to date.
  * @see calIObserver
@@ -990,6 +1038,20 @@ function agenda_calAdded(aCalendar) {
 agendaListbox.calendarObserver.onDefaultCalendarChanged = function(aCalendar) {
 };
 
+/**
+ * Updates the "Upcoming" section of today pane when preference soondays changes
+ **/
+agendaListbox.updateSoonSection =
+function updateSoonSection() {
+    this.soon.duration = this.soonDays;
+    this.soon.open = true;
+    let soonHeader = document.getElementById("nextweek-header");
+    if (soonHeader) {
+        soonHeader.setItem(this.soon, true);
+        agendaListbox.refreshPeriodDates(now());
+    }
+}
+
 /**
  * Updates the event considered "current". This goes through all "today" items
  * and sets the "current" attribute on all list items that are currently
@@ -1097,3 +1159,24 @@ function scheduleNextCurrentEventUpdate(aRefreshCallback, aMsUntil) {
     }
     gEventTimer.initWithCallback(udCallback, aMsUntil, gEventTimer.TYPE_ONE_SHOT);
 }
+
+/**
+ * Gets a right value for calendar.agendaListbox.soondays preference, avoid
+ * erroneus values edited in the lightning.js preference file
+ **/
+function getSoondaysPreference() {
+    let prefName = "calendar.agendaListbox.soondays";
+    let soonpref = Preferences.get(prefName, 5);
+
+    if (soonpref > 0 && soonpref <= 28) {
+        if (soonpref % 7 != 0) {
+            let intSoonpref = Math.floor(soonpref / 7) * 7;
+            soonpref = (intSoonpref == 0 ? soonpref : intSoonpref);
+            Preferences.set(prefName, soonpref, "INT");
+        }
+    } else {
+        soonpref = soonpref > 28 ? 28 : 1;
+        Preferences.set(prefName, soonpref, "INT");
+    }
+    return soonpref;
+}
