@@ -2,8 +2,8 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-const SUNBIRD_UID = "{718e30fb-e89b-41dd-9da7-e25a45638b28}";
-const FIREFOX_UID = "{ec8030f7-c20a-464f-9b0e-13a3a9e97384}";
+var SUNBIRD_UID = "{718e30fb-e89b-41dd-9da7-e25a45638b28}";
+var FIREFOX_UID = "{ec8030f7-c20a-464f-9b0e-13a3a9e97384}";
 
 Components.utils.import("resource://calendar/modules/calUtils.jsm");
 Components.utils.import("resource://gre/modules/Services.jsm");
@@ -35,7 +35,7 @@ var gMigrateWizard = {
                                                       1);
 
         migLOG("migrators: " + window.arguments.length);
-        for each (var migrator in window.arguments[0]) {
+        for (var migrator of window.arguments[0]) {
             var listItem = document.createElement("listitem");
             listItem.setAttribute("type", "checkbox");
             listItem.setAttribute("checked", true);
@@ -182,9 +182,9 @@ var gDataMigrator = {
                          this.checkWindowsMail,
                          this.checkIcal];
         // XXX also define a category and an interface here for pluggability
-        for each (var migrator in migrators) {
+        for (var migrator of migrators) {
             var migs = migrator.call(this);
-            for each (var dm in migs) {
+            for (var dm of migs) {
                 DMs.push(dm);
             }
         }
@@ -196,9 +196,9 @@ var gDataMigrator = {
         migLOG("DMs: " + DMs.length);
 
         var url = "chrome://calendar/content/calendar-migration-dialog.xul";
-//@line 207 "/usr/obj/ports/seamonkey-2.40/seamonkey-2.40/calendar/base/content/dialogs/calendar-migration-dialog.js"
+//@line 207 "/usr/obj/ports/seamonkey-2.46/seamonkey-2.46/calendar/base/content/dialogs/calendar-migration-dialog.js"
         openDialog(url, "migration", "modal,centerscreen,chrome,resizable=no,width=500,height=400", DMs);
-//@line 209 "/usr/obj/ports/seamonkey-2.40/seamonkey-2.40/calendar/base/content/dialogs/calendar-migration-dialog.js"
+//@line 209 "/usr/obj/ports/seamonkey-2.46/seamonkey-2.46/calendar/base/content/dialogs/calendar-migration-dialog.js"
     },
 
     /**
@@ -242,7 +242,7 @@ var gDataMigrator = {
             // For duplicate detection
             var calManager = getCalendarManager();
             var uris = [];
-            for each (var oldCal in calManager.getCalendars({})) {
+            for (var oldCal of calManager.getCalendars({})) {
                 uris.push(oldCal.uri);
             }
 
@@ -305,7 +305,7 @@ var gDataMigrator = {
         }
 
         // Now check all of the profiles in each of these folders for data
-        for each (var prof in profiles) {
+        for (var prof of profiles) {
             var dirEnum = prof.directoryEntries;
             while (dirEnum.hasMoreElements()) {
                 var profile = dirEnum.getNext().QueryInterface(Components.interfaces.nsIFile);
