@@ -428,7 +428,8 @@ function updateListboxDeleteButton(listboxId, buttonId) {
 function unitPluralForm(aLength, aUnit, aIncludeLength=true) {
     let unitProp = {"minutes": "unitMinutes",
                     "hours": "unitHours",
-                    "days": "unitDays"}[aUnit] || "unitMinutes";
+                    "days": "unitDays",
+                    "weeks": "unitWeeks"}[aUnit] || "unitMinutes";
 
     return PluralForm.get(aLength, cal.calGetString("calendar", unitProp))
                      .replace("#1", aIncludeLength ? aLength : "").trim();
@@ -534,7 +535,7 @@ function createXULElement(el) {
 function getSummarizedStyleValues(aXULElement, aStyleProps) {
     var retValue = 0;
     var cssStyleDeclares = document.defaultView.getComputedStyle(aXULElement, null);
-    for each (var prop in aStyleProps) {
+    for (var prop of aStyleProps) {
         retValue += parseInt(cssStyleDeclares.getPropertyValue(prop), 10);
     }
     return retValue;
@@ -623,13 +624,13 @@ function setupAttendanceMenu(aMenu, aItems) {
 
     goUpdateCommand("calendar_attendance_command");
 
-    let allSingle = aItems.every(function(x) !x.recurrenceId);
+    let allSingle = aItems.every(x => !x.recurrenceId);
     setElementValue(aMenu, allSingle ? "single" : "recurring", "itemType");
 
     let firstStatusOccurrences = aItems.length && getInvStat(aItems[0]);
     let firstStatusParents = aItems.length && getInvStat(aItems[0].parentItem);
-    let sameStatusOccurrences = aItems.every(function (x) getInvStat(x) == firstStatusOccurrences);
-    let sameStatusParents = aItems.every(function (x) getInvStat(x.parentItem) == firstStatusParents)
+    let sameStatusOccurrences = aItems.every(x => getInvStat(x) == firstStatusOccurrences);
+    let sameStatusParents = aItems.every(x => getInvStat(x.parentItem) == firstStatusParents);
 
     let occurrenceChildren = aMenu.getElementsByAttribute("value", firstStatusOccurrences);
     let parentsChildren = aMenu.getElementsByAttribute("value", firstStatusParents);
