@@ -75,6 +75,12 @@ pref("calendar.itip.updateInvitationForNewAttendeesOnly", false);
 //whether changes in email invitation updates should be displayed
 pref("calendar.itip.displayInvitationChanges", true);
 
+//whether for delegated invitations a delegatee's replies will be send also to delegator(s)
+pref("calendar.itip.notifyDelegatorOnReply", true);
+
+// whether to prefix the subject field for email invitation invites or updates.
+pref("calendar.itip.useInvitationSubjectPrefixes", true);
+
 // whether CalDAV (experimental) scheduling is enabled or not.
 pref("calendar.caldav.sched.enabled", false);
 
@@ -135,7 +141,7 @@ pref("calendar.threading.latency ", 250);
 pref("calendar.network.multirealm", false);
 
 // Set up user agent
-pref("calendar.useragent.extra", "Lightning/4.5");
+pref("calendar.useragent.extra", "Lightning/5.1");
 
 // Disable use of system colors in minimonth and calendar views
 pref("calendar.view.useSystemColors", false);
@@ -145,9 +151,9 @@ pref("calendar.view.useSystemColors", false);
 pref("calendar.filter.maxiterations", 50);
 
 // Backend to use. false: libical, true: ical.js
-//@line 151 "/usr/obj/ports/seamonkey-2.40/seamonkey-2.40/calendar/lightning/content/lightning.js"
+//@line 157 "/usr/obj/ports/seamonkey-2.46/seamonkey-2.46/calendar/lightning/content/lightning.js"
 pref("calendar.icaljs", false);
-//@line 153 "/usr/obj/ports/seamonkey-2.40/seamonkey-2.40/calendar/lightning/content/lightning.js"
+//@line 159 "/usr/obj/ports/seamonkey-2.46/seamonkey-2.46/calendar/lightning/content/lightning.js"
 
 // Calendar integration notification
 pref("calendar.integration.notify", true);
